@@ -1,3 +1,4 @@
+//Author: Dodji Seketeli
 /*
  *This file is part of the Nemiver project
  *
@@ -22,11 +23,15 @@
  *See COPYRIGHT file copyright information.
  */
 
+#include "config.h"
 #include <vector>
 #include <iostream>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-help.h>
+#ifdef WITH_GIO
+#include <giomm/init.h>
+#else
 #include <libgnomevfs/gnome-vfs-init.h>
+#endif // WITH_GIO
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/icontheme.h>
 #include "common/nmv-exception.h"
@@ -62,12 +67,18 @@ static const UString CONF_KEY_NEMIVER_WINDOW_MINIMUM_HEIGHT=
 class WorkbenchStaticInit {
     WorkbenchStaticInit ()
     {
+#ifdef WITH_GIO
+        Gio::init();
+#else
         gnome_vfs_init () ;
+#endif // WITH_GIO
     }
 
     ~WorkbenchStaticInit ()
     {
+#ifndef WITH_GIO
         gnome_vfs_shutdown () ;
+#endif  // WITH_GIO
     }
 
 public:
@@ -135,7 +146,7 @@ public:
     void set_title_extension (const UString &a_str) ;
     Glib::RefPtr<Gtk::UIManager>& get_ui_manager ()  ;
     IPerspective* get_perspective (const UString &a_name) ;
-    IConfMgr& get_configuration_manager ()  ;
+    IConfMgrSafePtr get_configuration_manager ()  ;
     Glib::RefPtr<Glib::MainContext> get_main_context ()  ;
     sigc::signal<void>& shutting_down_signal () ;
 };//end class Workbench
@@ -215,9 +226,20 @@ Workbench::on_quit_menu_item_action ()
 void
 Workbench::on_contents_menu_item_action ()
 {
-    gnome_help_display("nemiver.xml",
-                       NULL, /*link id*/
-                       NULL /*GError*/);
+    NEMIVER_TRY
+
+    UString help_url = "ghelp:nemiver";
+    LOG_DD ("launching help url: " << help_url);
+    UString path_to_help =
+        nemiver::common::env::build_path_to_help_file ("nemiver.xml");
+    THROW_IF_FAIL (!path_to_help.empty ());
+    UString cmd_line ("yelp " + path_to_help);
+    LOG_DD ("going to spawn: " << cmd_line);
+    bool is_ok = g_spawn_command_line_async (cmd_line.c_str (), NULL);
+    if (!is_ok) {
+        LOG_ERROR ("failed to spawn " << is_ok);
+    }
+    NEMIVER_CATCH
 }
 
 void
@@ -241,7 +263,7 @@ Workbench::on_about_menu_item_action ()
     documenters.push_back ("Jonathon Jongsma <jjongsma@gnome.org>");
     dialog.set_documenters (documenters);
 
-    dialog.set_website ("http://home.gna.org/nemiver/");
+    dialog.set_website ("http://www.gnome.org/projects/nemiver/");
     dialog.set_website_label (_("Project Website"));
 
     Glib::ustring license =
@@ -475,7 +497,7 @@ Workbench::get_perspective (const UString &a_name)
     return NULL;
 }
 
-IConfMgr&
+IConfMgrSafePtr
 Workbench::get_configuration_manager ()
 {
     THROW_IF_FAIL (m_priv) ;
@@ -495,7 +517,7 @@ Workbench::get_configuration_manager ()
                 "/desktop/gnome/interface/monospace_font_name") ;
     }
     THROW_IF_FAIL (m_priv->conf_mgr) ;
-    return *m_priv->conf_mgr ;
+    return m_priv->conf_mgr ;
 }
 
 Glib::RefPtr<Glib::MainContext>
@@ -524,36 +546,39 @@ Workbench::init_glade ()
     m_priv->glade = Gnome::Glade::Xml::create (file_path) ;
     THROW_IF_FAIL (m_priv->glade) ;
 
-    m_priv->root_window.reset
-           (ui_utils::get_widget_from_glade<Gtk::Window> (m_priv->glade,
-                                                          "workbench"));
-    THROW_IF_FAIL (m_priv->root_window) ;
-    // get the title of the root window as specified in the glade file and save
-    // it so that later we can add state-specific extensions to this base title
-    // if needed
+    Gtk::Widget *w =
+        ui_utils::get_widget_from_glade<Gtk::Window> (m_priv->glade,
+                                                      "workbench");
+    THROW_IF_FAIL (w);
+    m_priv->root_window.reset (dynamic_cast<Gtk::Window*>
+                                                (w->get_toplevel ()));
+    THROW_IF_FAIL (m_priv->root_window);
+    //get the title of the toplevel window as specified in the
+    //glade file and save
+    //it so that later we can add state-specific
+    //extensions to this base title
+    //if needed
     m_priv->base_title = m_priv->root_window->get_title ();
-
-   // m_priv->root_window->property_allow_shrink ().set_value (true) ;
-    m_priv->root_window->hide () ;
 }
 void
 
 Workbench::init_window ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+   LOG_FUNCTION_SCOPE_NORMAL_DD ;
 
     THROW_IF_FAIL (m_priv) ;
     THROW_IF_FAIL (m_priv->root_window) ;
-    IConfMgr &conf_mgr = get_configuration_manager () ;
+    IConfMgrSafePtr conf_mgr = get_configuration_manager () ;
+    THROW_IF_FAIL (conf_mgr) ;
 
     int width=0, height=0, pos_x=0, pos_y=0 ;
     LOG_DD ("getting windows geometry from confmgr ...") ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width) ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height) ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x) ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y) ;
     bool maximized=false ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized) ;
     LOG_DD ("got windows geometry from confmgr.") ;
 
     if (width) {
@@ -569,9 +594,13 @@ Workbench::init_window ()
     }
 
     //set the minimum width/height of nemiver, just in case.
-    width=700, height=500 ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_WIDTH, width) ;
-    conf_mgr.get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_HEIGHT, height) ;
+    width=0, height=0 ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_WIDTH, width) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_HEIGHT, height) ;
+    if (!width)
+        width = 700;
+    if (!height)
+        height = 500;
     m_priv->root_window->set_size_request (width, height) ;
     LOG_DD ("set windows min size to ("
             << (int) width
@@ -766,7 +795,8 @@ Workbench::save_window_geometry ()
 
     THROW_IF_FAIL (m_priv) ;
     THROW_IF_FAIL (m_priv->root_window) ;
-    IConfMgr &conf_mgr = get_configuration_manager () ;
+    IConfMgrSafePtr conf_mgr = get_configuration_manager () ;
+    THROW_IF_FAIL (conf_mgr) ;
 
     int width=0, height=0, pos_x=0, pos_y=0 ;
     m_priv->root_window->get_size (width, height) ;
@@ -774,13 +804,13 @@ Workbench::save_window_geometry ()
     bool maximized = (m_priv->root_window->get_window()->get_state()
                       & Gdk::WINDOW_STATE_MAXIMIZED);
 
-    conf_mgr.set_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized) ;
+    conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized) ;
     if (!maximized) {
         LOG_DD ("storing windows geometry to confmgr...") ;
-        conf_mgr.set_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width) ;
-        conf_mgr.set_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height) ;
-        conf_mgr.set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x) ;
-        conf_mgr.set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y) ;
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width) ;
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height) ;
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x) ;
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y) ;
         LOG_DD ("windows geometry stored to confmgr") ;
     } else {
         LOG_DD ("windows was maximized, didn't store its geometry") ;
